@@ -354,12 +354,15 @@ class Classifier:
        
         return 
 
-    def save(self, path=None, overwrite=False):
+    def save(self, dirname=None, path=None, overwrite=False):
         """
         Saves the trained classifier in a new directory named 'MicroLIA_models', 
         as well as the imputer and the features to use, if applicable.
         
         Args:
+            dirname (str): The name of the directory where the model folder will be saved.
+                This directory will be created, and therefore if it already exists
+                in the system an error will appear.
             path (str): Absolute path where the data folder will be saved
                 Defaults to None, in which case the directory is saved to the
                 local home directory.
@@ -376,6 +379,15 @@ class Classifier:
         if path[-1] != '/':
             path+='/'
 
+        if dirname is not None:
+            if dirname[-1] != '/':
+                dirname+='/'
+            path = path+dirname
+            try:
+                os.makedirs(path)
+            except FileExistsError:
+                raise ValueError('The dirname folder already exists!')
+
         try:
             os.mkdir(path+'MicroLIA_cnn_model')
         except FileExistsError:
@@ -433,26 +445,26 @@ class Classifier:
 
         try:
             self.model = load_model(path+'Keras_Model.h5', custom_objects={'f1_score': f1_score})
-            model = 'model,'
+            model = 'model'
         except:
             model = ''
             pass
 
         try:
             self.optimization_results = joblib.load(path+'HyperOpt_Results')
-            optimization_results = 'optimization_results,'
+            optimization_results = ', optimization_results,'
         except:
             optimization_results = '' 
             pass
 
         try:
             self.best_params = joblib.load(path+'Best_Params')
-            best_params = 'best_params'
+            best_params = ', best_params'
         except:
             best_params = '' 
             pass        
 
-        print('Successfully loaded the following class attributes: {} {} {}'.format(model, optimization_results, best_params))
+        print('Successfully loaded the following class attributes: {}{}{}'.format(model, optimization_results, best_params))
         
         self.path = path
         
