@@ -203,10 +203,14 @@ class Classifier:
             data = self.data_x[:]
             data[data>1e7], data[(data<1e-7)&(data>0)], data[data<-1e7] = 1e7, 1e-7, -1e7
 
-        self.feats_to_use, self.feature_history = borutashap_opt(data, self.data_y, boruta_trials=self.boruta_trials, model=self.boruta_model)
-        if len(self.feats_to_use) == 0:
-            print('No features selected, increase the number of n_trials when running MicroLIA.optimization.borutashap_opt(). Using all features...')
-            self.feats_to_use = np.arange(data.shape[1])
+        if self.feats_to_use is None:
+            self.feats_to_use, self.feature_history = borutashap_opt(data, self.data_y, boruta_trials=self.boruta_trials, model=self.boruta_model)
+            if len(self.feats_to_use) == 0:
+                print('No features selected, increase the number of n_trials when running MicroLIA.optimization.borutashap_opt(). Using all features...')
+                self.feats_to_use = np.arange(data.shape[1])
+        else:
+            print('feats_to_use attribute already exists, skipping feature selection...')
+
         #Re-construct the imputer with the selected features as
         #new predictions will only compute these metrics, need to fit again!
         if self.imp_method == 'KNN':
@@ -219,12 +223,15 @@ class Classifier:
         print("Fitting and returning final model...")
         self.model.fit(data_x, self.data_y)
         
-    def save(self, path=None, overwrite=False):
+    def save(self, dirname=None, path=None, overwrite=False):
         """
         Saves the trained classifier in a new directory named 'MicroLIA_models', 
         as well as the imputer and the features to use attributes, if not None.
         
         Args:
+            dirname (str): The name of the directory where the model folder will be saved.
+                This directory will be created, and therefore if it already exists
+                in the system an error will appear.
             path (str): Absolute path where the data folder will be saved
                 Defaults to None, in which case the directory is saved to the
                 local home directory.
@@ -233,13 +240,22 @@ class Classifier:
                 and created anew to avoid duplicate files. 
         """
         if self.model is None and self.imputer is None and self.feats_to_use is None:
-            raise ValueError('The models have not been created! Run classifier.create() first.')
+            raise ValueError('The models have not been created! Run the create() method first.')
 
         if path is None:
             path = str(Path.home())
         if path[-1] != '/':
             path+='/'
 
+        if dirname is not None:
+            if dirname[-1] != '/':
+                dirname+='/'
+            path = path+dirname
+            try:
+                os.makedirs(path)
+            except FileExistsError:
+                raise ValueError('The dirname folder already exists!')
+
         try:
             os.mkdir(path+'MicroLIA_ensemble_model')
         except FileExistsError:
@@ -301,40 +317,40 @@ class Classifier:
 
         try:
             self.imputer = joblib.load(path+'Imputer')
-            imputer = 'imputer'
+            imputer = ', imputer'
         except FileNotFoundError:
             imputer = ''
             pass 
 
         try:
             self.feats_to_use = joblib.load(path+'Feats_Index')
-            feats_to_use = 'feats_to_use'
+            feats_to_use = ', feats_to_use'
         except FileNotFoundError:
             feats_to_use = ''
             pass
 
         try:
             self.best_params = joblib.load(path+'Best_Params')
-            best_params = 'best_params'
+            best_params = ', best_params'
         except FileNotFoundError:
             best_params = ''
             pass
 
         try:
             self.feature_history = joblib.load(path+'FeatureOpt_Results')
-            feature_opt_results = 'feature_selection_results'
+            feature_opt_results = ', feature_selection_results'
         except FileNotFoundError:
             feature_opt_results = ''
             pass
 
         try:
             self.optimization_results = joblib.load(path+'HyperOpt_Results')
-            optimization_results = 'optimization_results'
+            optimization_results = ', optimization_results'
         except FileNotFoundError:
             optimization_results = '' 
             pass
 
-        print('Successfully loaded the following class attributes: {}, {}, {}, {}, {}, {}'.format(model, imputer, feats_to_use, best_params, feature_opt_results, optimization_results))
+        print('Successfully loaded the following class attributes: {}{}{}{}{}{}'.format(model, imputer, feats_to_use, best_params, feature_opt_results, optimization_results))
         
         self.path = path
 
@@ -390,7 +406,9 @@ class Classifier:
             clearly.
 
         Args:
-            data_y (ndarray, optional): If using XGBoost then the
+            data_y (ndarray, optional): A custom labels array, that coincides with
+                the labels in model.data_y. Defaults to None, in which case the
+                model.data_y labels are used.
             special_class (optional): The class label that you wish to highlight,
                 setting this optional parameter will 
             norm (bool): If True the data will be min-max normalized. Defaults
@@ -466,6 +484,8 @@ class Classifier:
                 data_y = self.data_y_ 
                 feats = np.unique(self.data_y_)
         else:
+            if isinstance(data_y, list):
+                data_y = np.array(data_y)
             feats = np.unique(data_y) 
 
         for count, feat in enumerate(feats):
@@ -792,7 +812,12 @@ class Classifier:
                 txt = t.get_text()
                 if 'Max Shadow' in txt:
                     t.set_color('red')
-                    ax.plot(y[-1], np.arange(len(x_names))[-1], marker='*', color='red')
+                    if include_rejected is False:
+                        ax.plot(y[-1], np.arange(len(x_names))[-1], marker='*', color='red')
+                    else:
+                        idx = 1 + len(rejected_indices)
+                        ax.plot(y[-idx], np.arange(len(x_names))[-idx], marker='*', color='red')
+
             ax.set_ylim((np.arange(len(x_names))[0]-0.5, np.arange(len(x_names))[-1]+0.5))
             ax.set_xlim((np.min(y)-1, np.max(y)+1))
             ax.invert_yaxis(), ax.invert_xaxis()
