@@ -8,7 +8,7 @@ import numpy as np
 from MicroLIA import features
 from inspect import getmembers, isfunction
 
-def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24):
+def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24, return_names=False):
     """
     This function will compute the statistics used to train the RF.
     Amplitude dependent features are computed first, after which the
@@ -32,13 +32,33 @@ def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24):
         defaults to True to convert and compute in flux. 
     zp : float
         Zeropoint of the instrument, defaults to 24.
-  
+    return_names : bool
+        If True the first output will be the stats array, and the second
+        will be the list of corresponding feature names. Defaults to False,
+        in which case only the stats array is returned.
+
     Returns
     -------
     stats : array
         All features to use for classification
     """
 
+    if isinstance(time, np.ndarray) is False:
+        if type(time) == list:
+            time = np.array(time)
+        else:
+            raise ValueError('time argument must be a list or array.')
+    if isinstance(mag, np.ndarray) is False:
+        if type(mag) == list:
+            mag = np.array(mag)
+        else:
+            raise ValueError('mag argument must be a list or array.')
+    if isinstance(magerr, np.ndarray) is False:
+        if type(magerr) == list:
+            magerr = np.array(magerr)
+        else:
+            raise ValueError('magerr argument must be a list or array.')
+        
     if convert is True:
         flux = 10**(-(mag-zp)/2.5)
         flux_err = (magerr*flux)/(2.5)*np.log(10)
@@ -53,6 +73,8 @@ def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24):
     all_features_functions = getmembers(features, isfunction)
 
     stats = []
+    feature_names = [] 
+
     #normal space
     counter = 0
     for func in all_features_functions:
@@ -66,13 +88,15 @@ def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24):
             else:
                 feature = func[1](time, norm_flux, norm_fluxerr)
 
-            if isinstance(feature, float) or isinstance(feature, int):
+            feature_names.append(func[0])
+
+            if np.isfinite(feature):
                 stats.append(feature)
             else:
-                stats.append(np.NaN)
+                stats.append(np.nan)
 
-        except:
-            stats.append(np.NaN)
+        except (ZeroDivisionError, ValueError):
+            stats.append(np.nan)
 
         counter += 1
             
@@ -94,22 +118,24 @@ def extract_all(time, mag, magerr, feats_to_use=None, convert=True, zp=24):
             else:
                 feature = func[1](time, norm_flux, norm_fluxerr)
 
-            if isinstance(feature, float) or isinstance(feature, int):
+            feature_names.append(func[0]+'_deriv')
+
+            if np.isfinite(feature):
                 stats.append(feature)
             else:
-                stats.append(np.NaN)
+                stats.append(np.nan)
 
-        except:
-            stats.append(np.NaN)
+        except (ZeroDivisionError, ValueError):
+            stats.append(np.nan)
             
         counter += 1
 
     stats = np.array(stats)
-    stats[np.isinf(stats)] = np.NaN
-    #stats[np.isnan(stats)] = 0
-    #stats[(stats<1e-6) * (stats>0)] = 1e-6
-    stats[stats<1e-7] = 1e-7
-    stats[stats>1e7] = 1e7
-    return stats
+    stats[np.isfinite(stats)==False] = np.nan
+    stats[stats>1e7], stats[(stats<1e-7)&(stats>0)], stats[stats<-1e7] = 1e7, 1e-7, -1e7
 
+    if return_names is False:
+        return stats
+    else:
+        return stats, feature_names
 
